| Copyright | (c) 2013-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.SES.SetIdentityHeadersInNotificationsEnabled
Description
Given an identity (an email address or a domain), sets whether Amazon SES includes the original email headers in the Amazon Simple Notification Service (Amazon SNS) notifications of a specified type.
This action is throttled at one request per second.
For more information about using notifications with Amazon SES, see the Amazon SES Developer Guide.
- setIdentityHeadersInNotificationsEnabled :: Text -> NotificationType -> Bool -> SetIdentityHeadersInNotificationsEnabled
- data SetIdentityHeadersInNotificationsEnabled
- sihineIdentity :: Lens' SetIdentityHeadersInNotificationsEnabled Text
- sihineNotificationType :: Lens' SetIdentityHeadersInNotificationsEnabled NotificationType
- sihineEnabled :: Lens' SetIdentityHeadersInNotificationsEnabled Bool
- setIdentityHeadersInNotificationsEnabledResponse :: Int -> SetIdentityHeadersInNotificationsEnabledResponse
- data SetIdentityHeadersInNotificationsEnabledResponse
- sihinersResponseStatus :: Lens' SetIdentityHeadersInNotificationsEnabledResponse Int
Creating a Request
setIdentityHeadersInNotificationsEnabled Source #
Arguments
| :: Text | |
| -> NotificationType | |
| -> Bool | |
| -> SetIdentityHeadersInNotificationsEnabled |
Creates a value of SetIdentityHeadersInNotificationsEnabled with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data SetIdentityHeadersInNotificationsEnabled Source #
Represents a request to set whether Amazon SES includes the original email headers in the Amazon SNS notifications of a specified type. For information about notifications, see the Amazon SES Developer Guide.
See: setIdentityHeadersInNotificationsEnabled smart constructor.
Instances
Request Lenses
sihineIdentity :: Lens' SetIdentityHeadersInNotificationsEnabled Text Source #
The identity for which to enable or disable headers in notifications. Examples: 'user\'example.com', 'example.com'.
sihineNotificationType :: Lens' SetIdentityHeadersInNotificationsEnabled NotificationType Source #
The notification type for which to enable or disable headers in notifications.
sihineEnabled :: Lens' SetIdentityHeadersInNotificationsEnabled Bool Source #
Sets whether Amazon SES includes the original email headers in Amazon SNS notifications of the specified notification type. A value of true specifies that Amazon SES will include headers in notifications, and a value of false specifies that Amazon SES will not include headers in notifications.
This value can only be set when NotificationType is already set to use a particular Amazon SNS topic.
Destructuring the Response
setIdentityHeadersInNotificationsEnabledResponse Source #
Creates a value of SetIdentityHeadersInNotificationsEnabledResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data SetIdentityHeadersInNotificationsEnabledResponse Source #
An empty element returned on a successful request.
See: setIdentityHeadersInNotificationsEnabledResponse smart constructor.
Instances
Response Lenses
sihinersResponseStatus :: Lens' SetIdentityHeadersInNotificationsEnabledResponse Int Source #
The response status code.